@@ -29,14 +29,16 @@ def test_Connection_plain_socket(db_kwargs):
     host = db_kwargs.get("host", "localhost")
     port = db_kwargs.get("port", 5432)
     with socket.create_connection((host, port)) as sock:
-        user = db_kwargs["user"]
-        password = db_kwargs["password"]
-        conn_params = {"sock": sock, "user": user, "password": password}
+        conn_params = {
+            "sock": sock,
+            "user": db_kwargs["user"],
+            "password": db_kwargs["password"],
+            "ssl_context": False,
+        }
 
-        con = Connection(**conn_params)
-
-        res = con.run("SELECT 1")
-        assert res[0][0] == 1
+        with Connection(**conn_params) as con:
+            res = con.run("SELECT 1")
+            assert res[0][0] == 1
 
 
 def test_database_missing(db_kwargs):
@@ -315,3 +317,13 @@ def test_failed_transaction_sql(con, sql):
 
     with pytest.raises(DatabaseError):
         con.run(sql)
+
+
+def test_parameter_statuses(con):
+    role_name = "Æthelred"
+    try:
+        con.run(f"create role {role_name}")
+    except DatabaseError:
+        pass
+    con.run(f"set session authorization '{role_name}'")
+    assert role_name == con.parameter_statuses["session_authorization"]
